#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-KbR0BQVGLsaFn6bmfXZ8e8
key:                  dhall-1.42.3-KbR0BQVGLsaFn6bmfXZ8e8
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  7c85728b3bf87bc2b6b49ab4eb9ab7e2
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-KbR0BQVGLsaFn6bmfXZ8e8
depends:
    Diff-0.5-2C7w3Xpas4N2eLiJ3AY0s2
    aeson-2.2.2.0-5ic0qdnYZHH6zFYkxFCOtx
    aeson-pretty-0.8.10-1ZdNlhHqboppnexgr2Ykp
    ansi-terminal-1.1-Jn1rGzu1G9XELC9vQ6NFDR
    atomic-write-0.2.1.1-CUPwVsG2OFREGTVz195blw base-4.18.2.1
    base16-bytestring-1.0.2.0-62KyUBG4ZgmGpNMNR9lueV
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-BUUMd5L4HIgpuJP9IYz4Q
    cborg-0.2.10.0-L5JYNawPPqSHYqm9CAOdqT
    cborg-json-0.2.6.0-J7O093LTrmOLcarAd2Z46A containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-F1ake6qAiC3Jcy2aZjKlNv
    data-fix-0.3.4-DHdQrIxOLGm7dP4bszWbLC deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-EodhgrOgz8CAJ5Cxs0XVgv exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-2tTeV4KHT7LAYyKjpDpw5g
    hashable-1.4.7.0-GIhdlNoQDSBAO6SjAK3pjT haskeline-0.8.2.1
    http-client-0.7.19-4NdB1UhXjPHpnfAoWeuwI
    http-client-tls-0.3.6.4-9nWpV5E7PWG8UoCj5iZhrt
    http-types-0.12.4-CXiZJUbLhJFHeSLHvVo6Rt
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-4OqWqitU2MSL2eA1wAwLXM
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-EKjXwcSJoi8IwfSCQFPAn2
    optparse-applicative-0.18.1.0-7SnpJ8KlnMr6TDIti6V1EO
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-8jYIqnaP9Aj5wtHTBoHRVM
    pretty-simple-4.1.4.0-LS3LizKfGgi8cPBHdtyd4E
    prettyprinter-1.7.1-C1cv8XSZ4iy3B6vMI1FDsE
    prettyprinter-ansi-terminal-1.1.4-CNlRFZ2GpdRBzmk8mIoYTm
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-3ttkxdCo3DY31RbKExXamW
    serialise-0.2.6.1-6JjjW9EzBOZHMHaW4zu2XJ template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-9SX2PWnHxYgIG9VUQ3AJ0Y
    text-short-0.1.6.1-L4Gaf6i3rNQ9QdIj8uKYwX
    th-lift-instances-0.1.20-9q8WyD32XeGADTKD8TAlCu time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-3g4IDjp0vr0De46QhKcu9n
    unordered-containers-0.2.20.1-1VPUCssH1vYLkUFtdr2cZd
    vector-0.13.2.0-DH6UT7zpR061zYDIVIbmaS

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

